@@ -3,6 +3,8 @@
 from logtail.frame import create_frame
 from logtail.handler import LogtailHandler
 from logtail.helpers import LogtailContext
+from sys import version_info
+import datetime
 import unittest2
 import logging
 
@@ -12,6 +14,16 @@ class TestLogtailLogEntry(unittest2.TestCase):
         log_record = logging.LogRecord("logtail-test", 20, "/some/path", 10, "Some log message", [], None)
         frame = create_frame(log_record, log_record.getMessage(), LogtailContext())
         self.assertTrue(frame['level'] == 'info')
+        # ISO timestamp must end with timezone info
+        self.assertTrue(frame['dt'].endswith("+00:00"))
+
+        # These tests require Python >= 3.7
+        if version_info.major == 2 or version_info.minor <= 6:
+            return
+        # Sent date matches log record date
+        date_ref = datetime.datetime.utcfromtimestamp(log_record.created).replace(tzinfo=datetime.timezone.utc)
+        date_sent = datetime.datetime.fromisoformat(frame['dt'])
+        self.assertEqual(date_ref, date_sent)
 
     def test_create_frame_with_extra(self):
         handler = LogtailHandler(source_token="some-source-token")
