@@ -28,32 +28,43 @@ class TestLogtailHandler(unittest2.TestCase):
             buffer_capacity=buffer_capacity,
             flush_interval=flush_interval
         )
-        self.assertEqual(handler.pipe._maxsize, buffer_capacity)
+        self.assertTrue(handler.pipe.empty())
 
     @mock.patch('logtail.handler.FlushWorker')
-    def test_handler_creates_and_starts_worker_from_args(self, MockWorker):
+    def test_handler_creates_and_starts_worker_from_args_after_first_log(self, MockWorker):
         buffer_capacity = 9
         flush_interval = 9
         handler = LogtailHandler(source_token=self.source_token, buffer_capacity=buffer_capacity, flush_interval=flush_interval)
+
+        self.assertFalse(MockWorker.called)
+
+        logger = logging.getLogger(__name__)
+        logger.handlers = []
+        logger.addHandler(handler)
+        logger.critical('hello')
+
         MockWorker.assert_called_with(
             handler.uploader,
             handler.pipe,
             buffer_capacity,
             flush_interval
         )
-        self.assertTrue(handler.flush_thread.start.called)
+        self.assertEqual(handler.flush_thread.start.call_count, 1)
 
     @mock.patch('logtail.handler.FlushWorker')
     def test_emit_starts_thread_if_not_alive(self, MockWorker):
         handler = LogtailHandler(source_token=self.source_token)
-        self.assertTrue(handler.flush_thread.start.call_count, 1)
-        handler.flush_thread.is_alive = mock.Mock(return_value=False)
 
         logger = logging.getLogger(__name__)
         logger.handlers = []
         logger.addHandler(handler)
         logger.critical('hello')
 
+        self.assertEqual(handler.flush_thread.start.call_count, 1)
+        handler.flush_thread.is_alive = mock.Mock(return_value=False)
+
+        logger.critical('hello')
+
         self.assertEqual(handler.flush_thread.start.call_count, 2)
 
     @mock.patch('logtail.handler.FlushWorker')
